pub struct BindGroupLayout {
pub label: String,
pub builder: BindGroupLayoutBuilder,
}Expand description
Structure for a bind group layout. Stores the layout description and builder data.
Fields
label: Stringbuilder: BindGroupLayoutBuilderImplementations
Sourceimpl BindGroupLayout
impl BindGroupLayout
Sourcepub fn new(
label: &str,
build_func: impl FnOnce(&mut BindGroupLayoutBuilder),
) -> Self
pub fn new( label: &str, build_func: impl FnOnce(&mut BindGroupLayoutBuilder), ) -> Self
Create a new bind group layout.
Arguments
label- The label of the bind group layout. Note that this label is only for GPU debugging purposes and is only used if GPU debugging is enabled.build_func- The function to build the bind group layout.
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Create a dummy empty bind group layout. This can be used for render bindings that don’t need a bind group.
Sourcepub fn build(
&self,
instance: &RenderInstanceData<'_>,
) -> Result<WgpuBindGroupLayout, RenderError>
pub fn build( &self, instance: &RenderInstanceData<'_>, ) -> Result<WgpuBindGroupLayout, RenderError>