pub struct BindGroupLayoutBuilder { /* private fields */ }Expand description
Builder for a bind group layout.
Implementations
Sourceimpl BindGroupLayoutBuilder
impl BindGroupLayoutBuilder
Sourcepub fn add_buffer(
&mut self,
binding: u32,
visibility: ShaderStages,
binding_type: BufferBindingType,
) -> &mut Self
pub fn add_buffer( &mut self, binding: u32, visibility: ShaderStages, binding_type: BufferBindingType, ) -> &mut Self
Add a buffer to the bind group.
Arguments
binding- The binding index of the buffer.visibility- The shader stages that can access the buffer.binding_type- The type of the buffer binding.
Sourcepub fn add_texture_view(
&mut self,
binding: u32,
visibility: ShaderStages,
multisampled: bool,
) -> &mut Self
pub fn add_texture_view( &mut self, binding: u32, visibility: ShaderStages, multisampled: bool, ) -> &mut Self
Add a texture to the bind group.
Arguments
binding- The binding index of the texture.visibility- The shader stages that can access the texture.multisampled- Whether the texture is multisampled.
Sourcepub fn add_storage_texture_view(
&mut self,
binding: u32,
format: TextureFormat,
) -> &mut Self
pub fn add_storage_texture_view( &mut self, binding: u32, format: TextureFormat, ) -> &mut Self
Add a storage texture view to the bind group. This is used for textures that will be read and written to in a compute shader.
Arguments
binding- The binding index of the texture.format- The format of the texture.atomic- Whether the texture will be used for atomic operations.
Sourcepub fn add_texture_array_view(
&mut self,
binding: u32,
visibility: ShaderStages,
) -> &mut Self
pub fn add_texture_array_view( &mut self, binding: u32, visibility: ShaderStages, ) -> &mut Self
Add a texture array to the bind group.
Arguments
binding- The binding index of the texture array.visibility- The shader stages that can access the texture array.
Sourcepub fn add_depth_texture_view(
&mut self,
binding: u32,
visibility: ShaderStages,
multisampled: bool,
) -> &mut Self
pub fn add_depth_texture_view( &mut self, binding: u32, visibility: ShaderStages, multisampled: bool, ) -> &mut Self
Add a depth texture to the bind group.
Arguments
binding- The binding index of the texture.visibility- The shader stages that can access the texture.multisampled- Whether the texture is multisampled.
Sourcepub fn add_texture_sampler(
&mut self,
binding: u32,
visibility: ShaderStages,
) -> &mut Self
pub fn add_texture_sampler( &mut self, binding: u32, visibility: ShaderStages, ) -> &mut Self
Add a texture to the bind group.
Arguments
binding- The binding index of the texture sampler.visibility- The shader stages that can access the sampler.
Sourcepub fn add_depth_texture_sampler(
&mut self,
binding: u32,
visibility: ShaderStages,
) -> &mut Self
pub fn add_depth_texture_sampler( &mut self, binding: u32, visibility: ShaderStages, ) -> &mut Self
Add a depth texture sampler to the bind group.
Arguments
binding- The binding index of the texture sampler.visibility- The shader stages that can access the sampler.